@@ -27,7 +27,7 @@ class JobClient(object):
     def call(self, routing_key, body=None,
              exchange='default', exchange_type='topic'):
         if settings.ENVIRONMENT == 'test':
-            return job_without_async(routing_key, body)
+            return None
 
         self.channel.exchange_declare(
             exchange=exchange,
@@ -37,7 +37,7 @@ class JobClient(object):
         self.channel.basic_publish(
             exchange=exchange,
             routing_key=routing_key,
-            body=json.dumps(body)
+            body=json.dumps(body, default=str)
         )
 
 
@@ -79,13 +79,6 @@ class JobServer(object):
             )
 
 
-def job_without_async(routing_key, body):
-    func = job_methods[routing_key]['func']
-    data = json.dumps(body)
-    func(json.loads(data))
-    return None
-
-
 def job_tasks(routing_key, exchange='default', exchange_type='topic',
               **kwargs):
     def wrapper(func):
