@@ -17,7 +17,7 @@ logger = logging.getLogger(__name__)
 def register_tasks():
     for apps in settings.INSTALLED_APPS:
         try:
-            __import__(apps + '.future_tasks')
+            # __import__(apps + '.future_tasks')
             __import__(apps + '.models')
         except ModuleNotFoundError:
             pass
