@@ -14,7 +14,7 @@ def signal_post_save(sender, instance, created, **kwargs):
 def send(routing_key):
     @staticmethod
     def wrapper(instances):
-        JobClient().call(routing_key, [model_to_dict(i) for i in instances])
+        JobClient().call(routing_key, [i.__dict__ for i in instances])
 
     return wrapper
 
